pub fn decode(data: impl AsRef<[u8]>) -> Result<Vec<u8>, DecodeError>Expand description
Decodes a hexadecimal string into bytes.
Errors
Returns DecodeError if the input length is odd or contains non-hex characters.
pub fn decode(data: impl AsRef<[u8]>) -> Result<Vec<u8>, DecodeError>Decodes a hexadecimal string into bytes.
Returns DecodeError if the input length is odd or contains non-hex characters.